"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.compute.v1.hardware_generation_pb2
import yandex.cloud.compute.v1.maintenance_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _IpVersion:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _IpVersionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_IpVersion.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    IP_VERSION_UNSPECIFIED: _IpVersion.ValueType  # 0
    IPV4: _IpVersion.ValueType  # 1
    """IPv4 address, for example 192.0.2.235."""
    IPV6: _IpVersion.ValueType  # 2
    """IPv6 address. Not available yet."""

class IpVersion(_IpVersion, metaclass=_IpVersionEnumTypeWrapper): ...

IP_VERSION_UNSPECIFIED: IpVersion.ValueType  # 0
IPV4: IpVersion.ValueType  # 1
"""IPv4 address, for example 192.0.2.235."""
IPV6: IpVersion.ValueType  # 2
"""IPv6 address. Not available yet."""
global___IpVersion = IpVersion

class _MetadataOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetadataOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetadataOption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METADATA_OPTION_UNSPECIFIED: _MetadataOption.ValueType  # 0
    ENABLED: _MetadataOption.ValueType  # 1
    """Option is enabled"""
    DISABLED: _MetadataOption.ValueType  # 2
    """Option is disabled"""

class MetadataOption(_MetadataOption, metaclass=_MetadataOptionEnumTypeWrapper): ...

METADATA_OPTION_UNSPECIFIED: MetadataOption.ValueType  # 0
ENABLED: MetadataOption.ValueType  # 1
"""Option is enabled"""
DISABLED: MetadataOption.ValueType  # 2
"""Option is disabled"""
global___MetadataOption = MetadataOption

@typing.final
class Instance(google.protobuf.message.Message):
    """An Instance resource. For more information, see [Instances](/docs/compute/concepts/vm)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Instance._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Instance._Status.ValueType  # 0
        PROVISIONING: Instance._Status.ValueType  # 1
        """Instance is waiting for resources to be allocated."""
        RUNNING: Instance._Status.ValueType  # 2
        """Instance is running normally."""
        STOPPING: Instance._Status.ValueType  # 3
        """Instance is being stopped."""
        STOPPED: Instance._Status.ValueType  # 4
        """Instance stopped."""
        STARTING: Instance._Status.ValueType  # 5
        """Instance is being started."""
        RESTARTING: Instance._Status.ValueType  # 6
        """Instance is being restarted."""
        UPDATING: Instance._Status.ValueType  # 7
        """Instance is being updated."""
        ERROR: Instance._Status.ValueType  # 8
        """Instance encountered a problem and cannot operate."""
        CRASHED: Instance._Status.ValueType  # 9
        """Instance crashed and will be restarted automatically."""
        DELETING: Instance._Status.ValueType  # 10
        """Instance is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Instance.Status.ValueType  # 0
    PROVISIONING: Instance.Status.ValueType  # 1
    """Instance is waiting for resources to be allocated."""
    RUNNING: Instance.Status.ValueType  # 2
    """Instance is running normally."""
    STOPPING: Instance.Status.ValueType  # 3
    """Instance is being stopped."""
    STOPPED: Instance.Status.ValueType  # 4
    """Instance stopped."""
    STARTING: Instance.Status.ValueType  # 5
    """Instance is being started."""
    RESTARTING: Instance.Status.ValueType  # 6
    """Instance is being restarted."""
    UPDATING: Instance.Status.ValueType  # 7
    """Instance is being updated."""
    ERROR: Instance.Status.ValueType  # 8
    """Instance encountered a problem and cannot operate."""
    CRASHED: Instance.Status.ValueType  # 9
    """Instance crashed and will be restarted automatically."""
    DELETING: Instance.Status.ValueType  # 10
    """Instance is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    METADATA_OPTIONS_FIELD_NUMBER: builtins.int
    BOOT_DISK_FIELD_NUMBER: builtins.int
    SECONDARY_DISKS_FIELD_NUMBER: builtins.int
    LOCAL_DISKS_FIELD_NUMBER: builtins.int
    FILESYSTEMS_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    SERIAL_PORT_SETTINGS_FIELD_NUMBER: builtins.int
    GPU_SETTINGS_FIELD_NUMBER: builtins.int
    FQDN_FIELD_NUMBER: builtins.int
    SCHEDULING_POLICY_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    PLACEMENT_POLICY_FIELD_NUMBER: builtins.int
    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    HOST_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    MAINTENANCE_GRACE_PERIOD_FIELD_NUMBER: builtins.int
    HARDWARE_GENERATION_FIELD_NUMBER: builtins.int
    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the instance."""
    folder_id: builtins.str
    """ID of the folder that the instance belongs to."""
    name: builtins.str
    """Name of the instance. 1-63 characters long."""
    description: builtins.str
    """Description of the instance. 0-256 characters long."""
    zone_id: builtins.str
    """ID of the availability zone where the instance resides."""
    platform_id: builtins.str
    """ID of the hardware platform configuration for the instance."""
    status: global___Instance.Status.ValueType
    """Status of the instance."""
    fqdn: builtins.str
    """A domain name of the instance. FQDN is defined by the server
    in the format `<hostname>.<region_id>.internal` when the instance is created.
    If the hostname were not specified when the instance was created, FQDN would be `<id>.auto.internal`.
    output only
    """
    service_account_id: builtins.str
    """ID of the service account to use for [authentication inside the instance](/docs/compute/operations/vm-connect/auth-inside-vm).
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    host_group_id: builtins.str
    """ID of the dedicated host group that the instance belongs to."""
    host_id: builtins.str
    """ID of the dedicated host that the instance belongs to."""
    maintenance_policy: yandex.cloud.compute.v1.maintenance_pb2.MaintenancePolicy.ValueType
    """Behaviour on maintenance events"""
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that the instance belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def resources(self) -> global___Resources:
        """Computing resources of the instance such as the amount of memory and number of cores."""

    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """The metadata `key:value` pairs assigned to this instance. This includes custom metadata and predefined keys.

        For example, you may use the metadata in order to provide your public SSH key to the instance.
        For more information, see [Metadata](/docs/compute/concepts/vm-metadata).
        """

    @property
    def metadata_options(self) -> global___MetadataOptions:
        """Options allow user to configure access to instance's metadata"""

    @property
    def boot_disk(self) -> global___AttachedDisk:
        """Boot disk that is attached to the instance."""

    @property
    def secondary_disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedDisk]:
        """Array of secondary disks that are attached to the instance."""

    @property
    def local_disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedLocalDisk]:
        """Array of local disks that are attached to the instance."""

    @property
    def filesystems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AttachedFilesystem]:
        """Array of filesystems that are attached to the instance."""

    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterface]:
        """Array of network interfaces that are attached to the instance."""

    @property
    def serial_port_settings(self) -> global___SerialPortSettings:
        """Serial port settings"""

    @property
    def gpu_settings(self) -> global___GpuSettings:
        """GPU settings"""

    @property
    def scheduling_policy(self) -> global___SchedulingPolicy:
        """Scheduling policy configuration."""

    @property
    def network_settings(self) -> global___NetworkSettings:
        """Network Settings"""

    @property
    def placement_policy(self) -> global___PlacementPolicy:
        """Placement policy configuration."""

    @property
    def maintenance_grace_period(self) -> google.protobuf.duration_pb2.Duration:
        """Time between notification via metadata service and maintenance"""

    @property
    def hardware_generation(self) -> yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration:
        """This feature set is inherited from the image/disk used as a boot one at the creation of the instance."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        platform_id: builtins.str = ...,
        resources: global___Resources | None = ...,
        status: global___Instance.Status.ValueType = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata_options: global___MetadataOptions | None = ...,
        boot_disk: global___AttachedDisk | None = ...,
        secondary_disks: collections.abc.Iterable[global___AttachedDisk] | None = ...,
        local_disks: collections.abc.Iterable[global___AttachedLocalDisk] | None = ...,
        filesystems: collections.abc.Iterable[global___AttachedFilesystem] | None = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterface] | None = ...,
        serial_port_settings: global___SerialPortSettings | None = ...,
        gpu_settings: global___GpuSettings | None = ...,
        fqdn: builtins.str = ...,
        scheduling_policy: global___SchedulingPolicy | None = ...,
        service_account_id: builtins.str = ...,
        network_settings: global___NetworkSettings | None = ...,
        placement_policy: global___PlacementPolicy | None = ...,
        host_group_id: builtins.str = ...,
        host_id: builtins.str = ...,
        maintenance_policy: yandex.cloud.compute.v1.maintenance_pb2.MaintenancePolicy.ValueType = ...,
        maintenance_grace_period: google.protobuf.duration_pb2.Duration | None = ...,
        hardware_generation: yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration | None = ...,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_disk", b"boot_disk", "created_at", b"created_at", "gpu_settings", b"gpu_settings", "hardware_generation", b"hardware_generation", "maintenance_grace_period", b"maintenance_grace_period", "metadata_options", b"metadata_options", "network_settings", b"network_settings", "placement_policy", b"placement_policy", "resources", b"resources", "scheduling_policy", b"scheduling_policy", "serial_port_settings", b"serial_port_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["boot_disk", b"boot_disk", "created_at", b"created_at", "description", b"description", "filesystems", b"filesystems", "folder_id", b"folder_id", "fqdn", b"fqdn", "gpu_settings", b"gpu_settings", "hardware_generation", b"hardware_generation", "host_group_id", b"host_group_id", "host_id", b"host_id", "id", b"id", "labels", b"labels", "local_disks", b"local_disks", "maintenance_grace_period", b"maintenance_grace_period", "maintenance_policy", b"maintenance_policy", "metadata", b"metadata", "metadata_options", b"metadata_options", "name", b"name", "network_interfaces", b"network_interfaces", "network_settings", b"network_settings", "placement_policy", b"placement_policy", "platform_id", b"platform_id", "reserved_instance_pool_id", b"reserved_instance_pool_id", "resources", b"resources", "scheduling_policy", b"scheduling_policy", "secondary_disks", b"secondary_disks", "serial_port_settings", b"serial_port_settings", "service_account_id", b"service_account_id", "status", b"status", "zone_id", b"zone_id"]) -> None: ...

global___Instance = Instance

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    GPUS_FIELD_NUMBER: builtins.int
    memory: builtins.int
    """The amount of memory available to the instance, specified in bytes."""
    cores: builtins.int
    """The number of cores available to the instance."""
    core_fraction: builtins.int
    """Baseline level of CPU performance with the ability to burst performance above that baseline level.
    This field sets baseline performance for each core.
    """
    gpus: builtins.int
    """The number of GPUs available to the instance."""
    def __init__(
        self,
        *,
        memory: builtins.int = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
        gpus: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "gpus", b"gpus", "memory", b"memory"]) -> None: ...

global___Resources = Resources

@typing.final
class AttachedDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Mode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AttachedDisk._Mode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MODE_UNSPECIFIED: AttachedDisk._Mode.ValueType  # 0
        READ_ONLY: AttachedDisk._Mode.ValueType  # 1
        """Read-only access."""
        READ_WRITE: AttachedDisk._Mode.ValueType  # 2
        """Read/Write access."""

    class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
    MODE_UNSPECIFIED: AttachedDisk.Mode.ValueType  # 0
    READ_ONLY: AttachedDisk.Mode.ValueType  # 1
    """Read-only access."""
    READ_WRITE: AttachedDisk.Mode.ValueType  # 2
    """Read/Write access."""

    MODE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_FIELD_NUMBER: builtins.int
    DISK_ID_FIELD_NUMBER: builtins.int
    mode: global___AttachedDisk.Mode.ValueType
    """Access mode to the Disk resource."""
    device_name: builtins.str
    """Serial number that is reflected into the /dev/disk/by-id/ tree
    of a Linux operating system running within the instance.

    This value can be used to reference the device for mounting, resizing, and so on, from within the instance.
    """
    auto_delete: builtins.bool
    """Specifies whether the disk will be auto-deleted when the instance is deleted."""
    disk_id: builtins.str
    """ID of the disk that is attached to the instance."""
    def __init__(
        self,
        *,
        mode: global___AttachedDisk.Mode.ValueType = ...,
        device_name: builtins.str = ...,
        auto_delete: builtins.bool = ...,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["auto_delete", b"auto_delete", "device_name", b"device_name", "disk_id", b"disk_id", "mode", b"mode"]) -> None: ...

global___AttachedDisk = AttachedDisk

@typing.final
class AttachedLocalDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    size: builtins.int
    """Size of the disk, specified in bytes."""
    device_name: builtins.str
    """Serial number that is reflected into the /dev/disk/by-id/ tree
    of a Linux operating system running within the instance.

    This value can be used to reference the device for mounting, resizing, and so on, from within the instance.
    """
    def __init__(
        self,
        *,
        size: builtins.int = ...,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "size", b"size"]) -> None: ...

global___AttachedLocalDisk = AttachedLocalDisk

@typing.final
class AttachedFilesystem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Mode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AttachedFilesystem._Mode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MODE_UNSPECIFIED: AttachedFilesystem._Mode.ValueType  # 0
        READ_ONLY: AttachedFilesystem._Mode.ValueType  # 1
        """Read-only access."""
        READ_WRITE: AttachedFilesystem._Mode.ValueType  # 2
        """Read/Write access."""

    class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
    MODE_UNSPECIFIED: AttachedFilesystem.Mode.ValueType  # 0
    READ_ONLY: AttachedFilesystem.Mode.ValueType  # 1
    """Read-only access."""
    READ_WRITE: AttachedFilesystem.Mode.ValueType  # 2
    """Read/Write access."""

    MODE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    FILESYSTEM_ID_FIELD_NUMBER: builtins.int
    mode: global___AttachedFilesystem.Mode.ValueType
    """Access mode to the filesystem."""
    device_name: builtins.str
    """Name of the device representing the filesystem on the instance.

    The name should be used for referencing the filesystem from within the instance
    when it's being mounted, resized etc.
    """
    filesystem_id: builtins.str
    """ID of the filesystem that is attached to the instance."""
    def __init__(
        self,
        *,
        mode: global___AttachedFilesystem.Mode.ValueType = ...,
        device_name: builtins.str = ...,
        filesystem_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "filesystem_id", b"filesystem_id", "mode", b"mode"]) -> None: ...

global___AttachedFilesystem = AttachedFilesystem

@typing.final
class NetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    MAC_ADDRESS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    PRIMARY_V4_ADDRESS_FIELD_NUMBER: builtins.int
    PRIMARY_V6_ADDRESS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    index: builtins.str
    """The index of the network interface, will be generated by the server, 0,1,2... etc if not specified."""
    mac_address: builtins.str
    """MAC address that is assigned to the network interface."""
    subnet_id: builtins.str
    """ID of the subnet."""
    @property
    def primary_v4_address(self) -> global___PrimaryAddress:
        """Primary IPv4 address that is assigned to the instance for this network interface."""

    @property
    def primary_v6_address(self) -> global___PrimaryAddress:
        """Primary IPv6 address that is assigned to the instance for this network interface. IPv6 not available yet."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ID's of security groups attached to the interface"""

    def __init__(
        self,
        *,
        index: builtins.str = ...,
        mac_address: builtins.str = ...,
        subnet_id: builtins.str = ...,
        primary_v4_address: global___PrimaryAddress | None = ...,
        primary_v6_address: global___PrimaryAddress | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["primary_v4_address", b"primary_v4_address", "primary_v6_address", b"primary_v6_address"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["index", b"index", "mac_address", b"mac_address", "primary_v4_address", b"primary_v4_address", "primary_v6_address", b"primary_v6_address", "security_group_ids", b"security_group_ids", "subnet_id", b"subnet_id"]) -> None: ...

global___NetworkInterface = NetworkInterface

@typing.final
class PrimaryAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    ONE_TO_ONE_NAT_FIELD_NUMBER: builtins.int
    DNS_RECORDS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """An IPv4 internal network address that is assigned to the instance for this network interface."""
    @property
    def one_to_one_nat(self) -> global___OneToOneNat:
        """One-to-one NAT configuration. If missing, NAT has not been set up."""

    @property
    def dns_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecord]:
        """Internal DNS configuration"""

    def __init__(
        self,
        *,
        address: builtins.str = ...,
        one_to_one_nat: global___OneToOneNat | None = ...,
        dns_records: collections.abc.Iterable[global___DnsRecord] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["one_to_one_nat", b"one_to_one_nat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "dns_records", b"dns_records", "one_to_one_nat", b"one_to_one_nat"]) -> None: ...

global___PrimaryAddress = PrimaryAddress

@typing.final
class OneToOneNat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    IP_VERSION_FIELD_NUMBER: builtins.int
    DNS_RECORDS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """An external IP address associated with this instance."""
    ip_version: global___IpVersion.ValueType
    """IP version for the external IP address."""
    @property
    def dns_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DnsRecord]:
        """External DNS configuration"""

    def __init__(
        self,
        *,
        address: builtins.str = ...,
        ip_version: global___IpVersion.ValueType = ...,
        dns_records: collections.abc.Iterable[global___DnsRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "dns_records", b"dns_records", "ip_version", b"ip_version"]) -> None: ...

global___OneToOneNat = OneToOneNat

@typing.final
class DnsRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    DNS_ZONE_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    PTR_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    """Name of the A/AAAA record as specified when creating the instance.
    Note that if `fqdn' has no trailing '.', it is specified relative to the zone (@see dns_zone_id).
    """
    dns_zone_id: builtins.str
    """DNS zone id for the record (optional, if not set, some private zone is used)."""
    ttl: builtins.int
    """DNS record ttl (optional, if not set, a reasonable default is used.)"""
    ptr: builtins.bool
    """When true, indicates there is a corresponding auto-created PTR DNS record."""
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        dns_zone_id: builtins.str = ...,
        ttl: builtins.int = ...,
        ptr: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_zone_id", b"dns_zone_id", "fqdn", b"fqdn", "ptr", b"ptr", "ttl", b"ttl"]) -> None: ...

global___DnsRecord = DnsRecord

@typing.final
class SchedulingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    preemptible: builtins.bool
    """True for short-lived compute instances. For more information, see [Preemptible VMs](/docs/compute/concepts/preemptible-vm)."""
    def __init__(
        self,
        *,
        preemptible: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["preemptible", b"preemptible"]) -> None: ...

global___SchedulingPolicy = SchedulingPolicy

@typing.final
class NetworkSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[NetworkSettings._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: NetworkSettings._Type.ValueType  # 0
        STANDARD: NetworkSettings._Type.ValueType  # 1
        """Standard network."""
        SOFTWARE_ACCELERATED: NetworkSettings._Type.ValueType  # 2
        """Software accelerated network."""
        HARDWARE_ACCELERATED: NetworkSettings._Type.ValueType  # 3
        """Hardware accelerated network (not available yet, reserved for future use)."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: NetworkSettings.Type.ValueType  # 0
    STANDARD: NetworkSettings.Type.ValueType  # 1
    """Standard network."""
    SOFTWARE_ACCELERATED: NetworkSettings.Type.ValueType  # 2
    """Software accelerated network."""
    HARDWARE_ACCELERATED: NetworkSettings.Type.ValueType  # 3
    """Hardware accelerated network (not available yet, reserved for future use)."""

    TYPE_FIELD_NUMBER: builtins.int
    type: global___NetworkSettings.Type.ValueType
    """Network Type"""
    def __init__(
        self,
        *,
        type: global___NetworkSettings.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type"]) -> None: ...

global___NetworkSettings = NetworkSettings

@typing.final
class GpuSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GPU_CLUSTER_ID_FIELD_NUMBER: builtins.int
    gpu_cluster_id: builtins.str
    """Attach instance to specified GPU cluster."""
    def __init__(
        self,
        *,
        gpu_cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gpu_cluster_id", b"gpu_cluster_id"]) -> None: ...

global___GpuSettings = GpuSettings

@typing.final
class PlacementPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HostAffinityRule(google.protobuf.message.Message):
        """Affinity definition"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Operator:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _OperatorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PlacementPolicy.HostAffinityRule._Operator.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            OPERATOR_UNSPECIFIED: PlacementPolicy.HostAffinityRule._Operator.ValueType  # 0
            IN: PlacementPolicy.HostAffinityRule._Operator.ValueType  # 1
            NOT_IN: PlacementPolicy.HostAffinityRule._Operator.ValueType  # 2

        class Operator(_Operator, metaclass=_OperatorEnumTypeWrapper): ...
        OPERATOR_UNSPECIFIED: PlacementPolicy.HostAffinityRule.Operator.ValueType  # 0
        IN: PlacementPolicy.HostAffinityRule.Operator.ValueType  # 1
        NOT_IN: PlacementPolicy.HostAffinityRule.Operator.ValueType  # 2

        KEY_FIELD_NUMBER: builtins.int
        OP_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        key: builtins.str
        """Affinity label or one of reserved values - 'yc.hostId', 'yc.hostGroupId'"""
        op: global___PlacementPolicy.HostAffinityRule.Operator.ValueType
        """Include or exclude action"""
        @property
        def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Affinity value or host ID or host group ID"""

        def __init__(
            self,
            *,
            key: builtins.str = ...,
            op: global___PlacementPolicy.HostAffinityRule.Operator.ValueType = ...,
            values: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "op", b"op", "values", b"values"]) -> None: ...

    PLACEMENT_GROUP_ID_FIELD_NUMBER: builtins.int
    HOST_AFFINITY_RULES_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_PARTITION_FIELD_NUMBER: builtins.int
    placement_group_id: builtins.str
    """Placement group ID."""
    placement_group_partition: builtins.int
    """Placement group partition"""
    @property
    def host_affinity_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlacementPolicy.HostAffinityRule]:
        """List of affinity rules. Scheduler will attempt to allocate instances according to order of rules."""

    def __init__(
        self,
        *,
        placement_group_id: builtins.str = ...,
        host_affinity_rules: collections.abc.Iterable[global___PlacementPolicy.HostAffinityRule] | None = ...,
        placement_group_partition: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_affinity_rules", b"host_affinity_rules", "placement_group_id", b"placement_group_id", "placement_group_partition", b"placement_group_partition"]) -> None: ...

global___PlacementPolicy = PlacementPolicy

@typing.final
class MetadataOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GCE_HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    AWS_V1_HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    GCE_HTTP_TOKEN_FIELD_NUMBER: builtins.int
    AWS_V1_HTTP_TOKEN_FIELD_NUMBER: builtins.int
    gce_http_endpoint: global___MetadataOption.ValueType
    """Enabled access to GCE flavored metadata"""
    aws_v1_http_endpoint: global___MetadataOption.ValueType
    """Enabled access to AWS flavored metadata (IMDSv1)"""
    gce_http_token: global___MetadataOption.ValueType
    """Enabled access to IAM credentials with GCE flavored metadata"""
    aws_v1_http_token: global___MetadataOption.ValueType
    """Enabled access to IAM credentials with AWS flavored metadata (IMDSv1)"""
    def __init__(
        self,
        *,
        gce_http_endpoint: global___MetadataOption.ValueType = ...,
        aws_v1_http_endpoint: global___MetadataOption.ValueType = ...,
        gce_http_token: global___MetadataOption.ValueType = ...,
        aws_v1_http_token: global___MetadataOption.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aws_v1_http_endpoint", b"aws_v1_http_endpoint", "aws_v1_http_token", b"aws_v1_http_token", "gce_http_endpoint", b"gce_http_endpoint", "gce_http_token", b"gce_http_token"]) -> None: ...

global___MetadataOptions = MetadataOptions

@typing.final
class SerialPortSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SSHAuthorization:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SSHAuthorizationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SerialPortSettings._SSHAuthorization.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SSH_AUTHORIZATION_UNSPECIFIED: SerialPortSettings._SSHAuthorization.ValueType  # 0
        INSTANCE_METADATA: SerialPortSettings._SSHAuthorization.ValueType  # 1
        """Authentication and authorization using SSH keys in instance metadata"""
        OS_LOGIN: SerialPortSettings._SSHAuthorization.ValueType  # 2
        """Authentication and authorization using Oslogin service"""

    class SSHAuthorization(_SSHAuthorization, metaclass=_SSHAuthorizationEnumTypeWrapper): ...
    SSH_AUTHORIZATION_UNSPECIFIED: SerialPortSettings.SSHAuthorization.ValueType  # 0
    INSTANCE_METADATA: SerialPortSettings.SSHAuthorization.ValueType  # 1
    """Authentication and authorization using SSH keys in instance metadata"""
    OS_LOGIN: SerialPortSettings.SSHAuthorization.ValueType  # 2
    """Authentication and authorization using Oslogin service"""

    SSH_AUTHORIZATION_FIELD_NUMBER: builtins.int
    ssh_authorization: global___SerialPortSettings.SSHAuthorization.ValueType
    """Authentication and authorization in serial console when using SSH protocol"""
    def __init__(
        self,
        *,
        ssh_authorization: global___SerialPortSettings.SSHAuthorization.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ssh_authorization", b"ssh_authorization"]) -> None: ...

global___SerialPortSettings = SerialPortSettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/storage/v1/presign_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/storage/v1/presign_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/storage/v1/presign_service.proto\x12\x17yandex.cloud.storage.v1\"\xed\x01\n\x14PresignObjectRequest\x12\x0f\n\x07\x65xpires\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12K\n\x07headers\x18\x04 \x03(\x0b\x32:.yandex.cloud.storage.v1.PresignObjectRequest.HeadersEntry\x12\x12\n\nversion_id\x18\x05 \x01(\t\x12\x15\n\ras_attachment\x18\x06 \x01(\x08\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x12PresignURLsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x14\n\x0cpresign_host\x18\x02 \x01(\t\x12>\n\x07objects\x18\x03 \x03(\x0b\x32-.yandex.cloud.storage.v1.PresignObjectRequest\"#\n\x13PresignURLsResponse\x12\x0c\n\x04urls\x18\x01 \x03(\t2u\n\x0ePresignService\x12\x63\n\x06\x43reate\x12+.yandex.cloud.storage.v1.PresignURLsRequest\x1a,.yandex.cloud.storage.v1.PresignURLsResponseBb\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.presign_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_PRESIGNOBJECTREQUEST']._serialized_start=75
  _globals['_PRESIGNOBJECTREQUEST']._serialized_end=312
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._serialized_start=266
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._serialized_end=312
  _globals['_PRESIGNURLSREQUEST']._serialized_start=314
  _globals['_PRESIGNURLSREQUEST']._serialized_end=441
  _globals['_PRESIGNURLSRESPONSE']._serialized_start=443
  _globals['_PRESIGNURLSRESPONSE']._serialized_end=478
  _globals['_PRESIGNSERVICE']._serialized_start=480
  _globals['_PRESIGNSERVICE']._serialized_end=597
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.configuration_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    configuration_id: builtins.str
    """ID of the Configuration resource to return.

    To get the configuration ID, use a [ConfigurationService.List] request.
    """
    folder_id: builtins.str
    """ID of the folder to return a Configuration resource for.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    def __init__(
        self,
        *,
        configuration_id: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["configuration_id", b"configuration_id", "folder_id", b"folder_id"]) -> None: ...

global___GetConfigurationRequest = GetConfigurationRequest

@typing.final
class ListConfigurationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListConfigurationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListConfigurationsResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "name"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name"].
    Both snake_case and camelCase are supported for fields.
    """
    folder_id: builtins.str
    """ID of the folder to return a Configuration resource for.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListConfigurationsRequest = ListConfigurationsRequest

@typing.final
class ListConfigurationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListConfigurationsRequest.page_size], use `next_page_token` as the value
    for the [ListConfigurationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.configuration_pb2.Configuration]:
        """List of Configuration resources."""

    def __init__(
        self,
        *,
        configurations: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.configuration_pb2.Configuration] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["configurations", b"configurations", "next_page_token", b"next_page_token"]) -> None: ...

global___ListConfigurationsResponse = ListConfigurationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.apigateway.v1.apigateway_pb2
import yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ApiGatewayServiceStub:
    """A set of methods for managing API gateways."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetApiGatewayRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_pb2.ApiGateway,
    ]
    """Returns the specified API gateway. Note that only API gateway basic attributes are returned.
    To get associated openapi specification, make a [GetOpenapiSpec] request.

    To get the list of all available API gateways, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayResponse,
    ]
    """Retrieves the list of API gateways in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.CreateApiGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an API gateway in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.UpdateApiGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified API gateway."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.DeleteApiGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified API gateway."""

    AddDomain: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.AddDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches domain to the specified API gateway."""

    RemoveDomain: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.RemoveDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches domain from the specified API gateway."""

    GetOpenapiSpec: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecResponse,
    ]
    """Returns the OpenAPI specification of specified API gateway."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsResponse,
    ]
    """Lists operations for the specified API gateway."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified API gateway."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified API gateway."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified API gateway."""

class ApiGatewayServiceAsyncStub:
    """A set of methods for managing API gateways."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetApiGatewayRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_pb2.ApiGateway,
    ]
    """Returns the specified API gateway. Note that only API gateway basic attributes are returned.
    To get associated openapi specification, make a [GetOpenapiSpec] request.

    To get the list of all available API gateways, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayResponse,
    ]
    """Retrieves the list of API gateways in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.CreateApiGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an API gateway in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.UpdateApiGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified API gateway."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.DeleteApiGatewayRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified API gateway."""

    AddDomain: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.AddDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Attaches domain to the specified API gateway."""

    RemoveDomain: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.RemoveDomainRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Detaches domain from the specified API gateway."""

    GetOpenapiSpec: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecResponse,
    ]
    """Returns the OpenAPI specification of specified API gateway."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsRequest,
        yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsResponse,
    ]
    """Lists operations for the specified API gateway."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified API gateway."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified API gateway."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified API gateway."""

class ApiGatewayServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing API gateways."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetApiGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.v1.apigateway_pb2.ApiGateway, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.v1.apigateway_pb2.ApiGateway]]:
        """Returns the specified API gateway. Note that only API gateway basic attributes are returned.
        To get associated openapi specification, make a [GetOpenapiSpec] request.

        To get the list of all available API gateways, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayResponse, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListApiGatewayResponse]]:
        """Retrieves the list of API gateways in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.CreateApiGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an API gateway in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.UpdateApiGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified API gateway."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.DeleteApiGatewayRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified API gateway."""

    @abc.abstractmethod
    def AddDomain(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.AddDomainRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Attaches domain to the specified API gateway."""

    @abc.abstractmethod
    def RemoveDomain(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.RemoveDomainRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Detaches domain from the specified API gateway."""

    @abc.abstractmethod
    def GetOpenapiSpec(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecResponse, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.GetOpenapiSpecResponse]]:
        """Returns the OpenAPI specification of specified API gateway."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsResponse, collections.abc.Awaitable[yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2.ListOperationsResponse]]:
        """Lists operations for the specified API gateway."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified API gateway."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified API gateway."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified API gateway."""

def add_ApiGatewayServiceServicer_to_server(servicer: ApiGatewayServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.style_preset_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetStylePresetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    style_preset_id: builtins.str
    """ID of the style preset to retrieve."""
    def __init__(
        self,
        *,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["style_preset_id", b"style_preset_id"]) -> None: ...

global___GetStylePresetRequest = GetStylePresetRequest

@typing.final
class ListStylePresetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the style presets to list."""
    page_size: builtins.int
    """The maximum number of style presets to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListStylePresetsResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "createdAt desc").
    Default: "id asc".
    Supported fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned style presets.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'dark' AND id='preset-1'`

    Filterable fields: ["id", "title"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListStylePresetsRequest = ListStylePresetsRequest

@typing.final
class ListStylePresetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESETS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def style_presets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.style_preset_pb2.StylePreset]:
        """List of style presets matching the request criteria.
        May be empty if no style presets match the criteria or if the channel has no style presets.
        """

    def __init__(
        self,
        *,
        style_presets: collections.abc.Iterable[yandex.cloud.video.v1.style_preset_pb2.StylePreset] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "style_presets", b"style_presets"]) -> None: ...

global___ListStylePresetsResponse = ListStylePresetsResponse

@typing.final
class CreateStylePresetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    WIDGET_TEXT_COLOR_PRIMARY_FIELD_NUMBER: builtins.int
    WIDGET_TEXT_COLOR_SECONDARY_FIELD_NUMBER: builtins.int
    WIDGET_ACCENT_COLOR_FIELD_NUMBER: builtins.int
    WIDGET_BLOCK_GAP_FIELD_NUMBER: builtins.int
    WIDGET_BLOCK_SEPARATOR_COLOR_FIELD_NUMBER: builtins.int
    PLAYER_BORDER_RADIUS_FIELD_NUMBER: builtins.int
    PLAYER_COLOR_FIELD_NUMBER: builtins.int
    PLAYLIST_SELECTED_ITEM_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    PLAYLIST_ITEM_BORDER_RADIUS_FIELD_NUMBER: builtins.int
    PLAYLIST_ITEM_GAP_FIELD_NUMBER: builtins.int
    PLAYLIST_LOCATION_FIELD_NUMBER: builtins.int
    RIGHT_WIDGETS_FIELD_NUMBER: builtins.int
    BOTTOM_WIDGETS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    title: builtins.str
    """Style preset title."""
    background_color: builtins.str
    """Background color."""
    widget_text_color_primary: builtins.str
    """Widget primary text color."""
    widget_text_color_secondary: builtins.str
    """Widget secondary text color."""
    widget_accent_color: builtins.str
    """Widget accent color."""
    widget_block_gap: builtins.int
    """Gap between widget blocks."""
    widget_block_separator_color: builtins.str
    """Line color between widget blocks."""
    player_border_radius: builtins.int
    """Player border radius."""
    player_color: builtins.str
    """Player color."""
    playlist_selected_item_background_color: builtins.str
    """Background color of selected video in playlist."""
    playlist_item_border_radius: builtins.int
    """Playlist item border radius."""
    playlist_item_gap: builtins.int
    """Gap between videos in playlist."""
    playlist_location: yandex.cloud.video.v1.style_preset_pb2.StylePreset.WidgetLocation.ValueType
    """Playlist widget location."""
    @property
    def right_widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.style_preset_pb2.Widget]:
        """List of widgets to display to the right of the player."""

    @property
    def bottom_widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.style_preset_pb2.Widget]:
        """List of widgets to display below the player."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        background_color: builtins.str = ...,
        widget_text_color_primary: builtins.str = ...,
        widget_text_color_secondary: builtins.str = ...,
        widget_accent_color: builtins.str = ...,
        widget_block_gap: builtins.int = ...,
        widget_block_separator_color: builtins.str = ...,
        player_border_radius: builtins.int = ...,
        player_color: builtins.str = ...,
        playlist_selected_item_background_color: builtins.str = ...,
        playlist_item_border_radius: builtins.int = ...,
        playlist_item_gap: builtins.int = ...,
        playlist_location: yandex.cloud.video.v1.style_preset_pb2.StylePreset.WidgetLocation.ValueType = ...,
        right_widgets: collections.abc.Iterable[yandex.cloud.video.v1.style_preset_pb2.Widget] | None = ...,
        bottom_widgets: collections.abc.Iterable[yandex.cloud.video.v1.style_preset_pb2.Widget] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["background_color", b"background_color", "bottom_widgets", b"bottom_widgets", "channel_id", b"channel_id", "player_border_radius", b"player_border_radius", "player_color", b"player_color", "playlist_item_border_radius", b"playlist_item_border_radius", "playlist_item_gap", b"playlist_item_gap", "playlist_location", b"playlist_location", "playlist_selected_item_background_color", b"playlist_selected_item_background_color", "right_widgets", b"right_widgets", "title", b"title", "widget_accent_color", b"widget_accent_color", "widget_block_gap", b"widget_block_gap", "widget_block_separator_color", b"widget_block_separator_color", "widget_text_color_primary", b"widget_text_color_primary", "widget_text_color_secondary", b"widget_text_color_secondary"]) -> None: ...

global___CreateStylePresetRequest = CreateStylePresetRequest

@typing.final
class CreateStylePresetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    style_preset_id: builtins.str
    """ID of the style preset being created."""
    def __init__(
        self,
        *,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["style_preset_id", b"style_preset_id"]) -> None: ...

global___CreateStylePresetMetadata = CreateStylePresetMetadata

@typing.final
class UpdateStylePresetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    WIDGET_TEXT_COLOR_PRIMARY_FIELD_NUMBER: builtins.int
    WIDGET_TEXT_COLOR_SECONDARY_FIELD_NUMBER: builtins.int
    WIDGET_ACCENT_COLOR_FIELD_NUMBER: builtins.int
    WIDGET_BLOCK_GAP_FIELD_NUMBER: builtins.int
    WIDGET_BLOCK_SEPARATOR_COLOR_FIELD_NUMBER: builtins.int
    PLAYER_BORDER_RADIUS_FIELD_NUMBER: builtins.int
    PLAYER_COLOR_FIELD_NUMBER: builtins.int
    PLAYLIST_SELECTED_ITEM_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    PLAYLIST_ITEM_BORDER_RADIUS_FIELD_NUMBER: builtins.int
    PLAYLIST_ITEM_GAP_FIELD_NUMBER: builtins.int
    PLAYLIST_LOCATION_FIELD_NUMBER: builtins.int
    RIGHT_WIDGETS_FIELD_NUMBER: builtins.int
    BOTTOM_WIDGETS_FIELD_NUMBER: builtins.int
    style_preset_id: builtins.str
    """ID of the style preset."""
    title: builtins.str
    """Style preset title."""
    background_color: builtins.str
    """Background color."""
    widget_text_color_primary: builtins.str
    """Widget primary text color."""
    widget_text_color_secondary: builtins.str
    """Widget secondary text color."""
    widget_accent_color: builtins.str
    """Widget accent color."""
    widget_block_gap: builtins.int
    """Gap between widget blocks."""
    widget_block_separator_color: builtins.str
    """Line color between widget blocks."""
    player_border_radius: builtins.int
    """Player border radius."""
    player_color: builtins.str
    """Player color."""
    playlist_selected_item_background_color: builtins.str
    """Background color of selected video in playlist."""
    playlist_item_border_radius: builtins.int
    """Playlist item border radius."""
    playlist_item_gap: builtins.int
    """Gap between videos in playlist."""
    playlist_location: yandex.cloud.video.v1.style_preset_pb2.StylePreset.WidgetLocation.ValueType
    """Playlist widget location."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the style preset should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def right_widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.style_preset_pb2.Widget]:
        """List of widgets to display to the right of the player."""

    @property
    def bottom_widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.style_preset_pb2.Widget]:
        """List of widgets to display below the player."""

    def __init__(
        self,
        *,
        style_preset_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        background_color: builtins.str = ...,
        widget_text_color_primary: builtins.str = ...,
        widget_text_color_secondary: builtins.str = ...,
        widget_accent_color: builtins.str = ...,
        widget_block_gap: builtins.int = ...,
        widget_block_separator_color: builtins.str = ...,
        player_border_radius: builtins.int = ...,
        player_color: builtins.str = ...,
        playlist_selected_item_background_color: builtins.str = ...,
        playlist_item_border_radius: builtins.int = ...,
        playlist_item_gap: builtins.int = ...,
        playlist_location: yandex.cloud.video.v1.style_preset_pb2.StylePreset.WidgetLocation.ValueType = ...,
        right_widgets: collections.abc.Iterable[yandex.cloud.video.v1.style_preset_pb2.Widget] | None = ...,
        bottom_widgets: collections.abc.Iterable[yandex.cloud.video.v1.style_preset_pb2.Widget] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["background_color", b"background_color", "bottom_widgets", b"bottom_widgets", "field_mask", b"field_mask", "player_border_radius", b"player_border_radius", "player_color", b"player_color", "playlist_item_border_radius", b"playlist_item_border_radius", "playlist_item_gap", b"playlist_item_gap", "playlist_location", b"playlist_location", "playlist_selected_item_background_color", b"playlist_selected_item_background_color", "right_widgets", b"right_widgets", "style_preset_id", b"style_preset_id", "title", b"title", "widget_accent_color", b"widget_accent_color", "widget_block_gap", b"widget_block_gap", "widget_block_separator_color", b"widget_block_separator_color", "widget_text_color_primary", b"widget_text_color_primary", "widget_text_color_secondary", b"widget_text_color_secondary"]) -> None: ...

global___UpdateStylePresetRequest = UpdateStylePresetRequest

@typing.final
class UpdateStylePresetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    style_preset_id: builtins.str
    """ID of the style preset being updated."""
    def __init__(
        self,
        *,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["style_preset_id", b"style_preset_id"]) -> None: ...

global___UpdateStylePresetMetadata = UpdateStylePresetMetadata

@typing.final
class DeleteStylePresetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    style_preset_id: builtins.str
    """ID of the style preset to delete.
    The style preset must not be in use by any videos, episodes, or playlists.
    """
    def __init__(
        self,
        *,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["style_preset_id", b"style_preset_id"]) -> None: ...

global___DeleteStylePresetRequest = DeleteStylePresetRequest

@typing.final
class DeleteStylePresetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    style_preset_id: builtins.str
    """ID of the style preset being deleted.
    This identifier can be used to track the style preset deletion operation.
    """
    def __init__(
        self,
        *,
        style_preset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["style_preset_id", b"style_preset_id"]) -> None: ...

global___DeleteStylePresetMetadata = DeleteStylePresetMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Backup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    SOURCE_CLUSTER_ID_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    INDICES_FIELD_NUMBER: builtins.int
    OPENSEARCH_VERSION_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    INDICES_TOTAL_FIELD_NUMBER: builtins.int
    INCREMENTAL_SIZE_BYTES_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_BYTES_FIELD_NUMBER: builtins.int
    FREE_SPACE_REQUIRED_BYTES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. ID of the backup."""
    folder_id: builtins.str
    """ID of the folder that the backup belongs to."""
    source_cluster_id: builtins.str
    """ID of the OpenSearch cluster that the backup was created for."""
    opensearch_version: builtins.str
    """OpenSearch version used to create the backup."""
    size_bytes: builtins.int
    """Size of the backup in bytes."""
    indices_total: builtins.int
    """The number of indices in the backup."""
    incremental_size_bytes: builtins.int
    """Size of files which were copied as part of the incremental snapshot."""
    total_size_bytes: builtins.int
    """Size of files that are referenced by the snapshot."""
    free_space_required_bytes: builtins.int
    """The space amount required to restore from this backup."""
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the backup operation was started."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the backup operation was completed."""

    @property
    def indices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of indices in the backup."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        source_cluster_id: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        indices: collections.abc.Iterable[builtins.str] | None = ...,
        opensearch_version: builtins.str = ...,
        size_bytes: builtins.int = ...,
        indices_total: builtins.int = ...,
        incremental_size_bytes: builtins.int = ...,
        total_size_bytes: builtins.int = ...,
        free_space_required_bytes: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "folder_id", b"folder_id", "free_space_required_bytes", b"free_space_required_bytes", "id", b"id", "incremental_size_bytes", b"incremental_size_bytes", "indices", b"indices", "indices_total", b"indices_total", "opensearch_version", b"opensearch_version", "size_bytes", b"size_bytes", "source_cluster_id", b"source_cluster_id", "started_at", b"started_at", "total_size_bytes", b"total_size_bytes"]) -> None: ...

global___Backup = Backup

@typing.final
class SnapshotManagement(google.protobuf.message.Message):
    """Snapshot management configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_SCHEDULE_FIELD_NUMBER: builtins.int
    SNAPSHOT_MAX_AGE_DAYS_FIELD_NUMBER: builtins.int
    @property
    def snapshot_schedule(self) -> global___SnapshotSchedule:
        """Snapshot creation schedule"""

    @property
    def snapshot_max_age_days(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Snapshot max age in days"""

    def __init__(
        self,
        *,
        snapshot_schedule: global___SnapshotSchedule | None = ...,
        snapshot_max_age_days: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["snapshot_max_age_days", b"snapshot_max_age_days", "snapshot_schedule", b"snapshot_schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["snapshot_max_age_days", b"snapshot_max_age_days", "snapshot_schedule", b"snapshot_schedule"]) -> None: ...

global___SnapshotManagement = SnapshotManagement

@typing.final
class SnapshotSchedule(google.protobuf.message.Message):
    """Snapshot creation schedule"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURLY_SNAPSHOT_SCHEDULE_FIELD_NUMBER: builtins.int
    DAILY_SNAPSHOT_SCHEDULE_FIELD_NUMBER: builtins.int
    WEEKLY_SNAPSHOT_SCHEDULE_FIELD_NUMBER: builtins.int
    @property
    def hourly_snapshot_schedule(self) -> global___HourlySnapshotSchedule:
        """Hourly based snapshot schedule"""

    @property
    def daily_snapshot_schedule(self) -> global___DailySnapshotSchedule:
        """Daily based snapshot schedule"""

    @property
    def weekly_snapshot_schedule(self) -> global___WeeklySnapshotSchedule:
        """Weekly based snapshot schedule"""

    def __init__(
        self,
        *,
        hourly_snapshot_schedule: global___HourlySnapshotSchedule | None = ...,
        daily_snapshot_schedule: global___DailySnapshotSchedule | None = ...,
        weekly_snapshot_schedule: global___WeeklySnapshotSchedule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["daily_snapshot_schedule", b"daily_snapshot_schedule", "hourly_snapshot_schedule", b"hourly_snapshot_schedule", "schedule", b"schedule", "weekly_snapshot_schedule", b"weekly_snapshot_schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["daily_snapshot_schedule", b"daily_snapshot_schedule", "hourly_snapshot_schedule", b"hourly_snapshot_schedule", "schedule", b"schedule", "weekly_snapshot_schedule", b"weekly_snapshot_schedule"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["schedule", b"schedule"]) -> typing.Literal["hourly_snapshot_schedule", "daily_snapshot_schedule", "weekly_snapshot_schedule"] | None: ...

global___SnapshotSchedule = SnapshotSchedule

@typing.final
class HourlySnapshotSchedule(google.protobuf.message.Message):
    """Hourly based snapshot schedule"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MINUTE_FIELD_NUMBER: builtins.int
    minute: builtins.int
    """The minute of the hour at which the backup should be created."""
    def __init__(
        self,
        *,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["minute", b"minute"]) -> None: ...

global___HourlySnapshotSchedule = HourlySnapshotSchedule

@typing.final
class DailySnapshotSchedule(google.protobuf.message.Message):
    """Daily based snapshot schedule"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    hour: builtins.int
    """The hour of the day in UTC timezone at which the backup should be created."""
    minute: builtins.int
    """The minute of the hour at which the backup should be created."""
    def __init__(
        self,
        *,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hour", b"hour", "minute", b"minute"]) -> None: ...

global___DailySnapshotSchedule = DailySnapshotSchedule

@typing.final
class WeeklySnapshotSchedule(google.protobuf.message.Message):
    """Weekly based snapshot schedule"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WeekDay:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WeekDayEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WeeklySnapshotSchedule._WeekDay.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WEEK_DAY_UNSPECIFIED: WeeklySnapshotSchedule._WeekDay.ValueType  # 0
        MON: WeeklySnapshotSchedule._WeekDay.ValueType  # 1
        TUE: WeeklySnapshotSchedule._WeekDay.ValueType  # 2
        WED: WeeklySnapshotSchedule._WeekDay.ValueType  # 3
        THU: WeeklySnapshotSchedule._WeekDay.ValueType  # 4
        FRI: WeeklySnapshotSchedule._WeekDay.ValueType  # 5
        SAT: WeeklySnapshotSchedule._WeekDay.ValueType  # 6
        SUN: WeeklySnapshotSchedule._WeekDay.ValueType  # 7

    class WeekDay(_WeekDay, metaclass=_WeekDayEnumTypeWrapper):
        """Day of the week"""

    WEEK_DAY_UNSPECIFIED: WeeklySnapshotSchedule.WeekDay.ValueType  # 0
    MON: WeeklySnapshotSchedule.WeekDay.ValueType  # 1
    TUE: WeeklySnapshotSchedule.WeekDay.ValueType  # 2
    WED: WeeklySnapshotSchedule.WeekDay.ValueType  # 3
    THU: WeeklySnapshotSchedule.WeekDay.ValueType  # 4
    FRI: WeeklySnapshotSchedule.WeekDay.ValueType  # 5
    SAT: WeeklySnapshotSchedule.WeekDay.ValueType  # 6
    SUN: WeeklySnapshotSchedule.WeekDay.ValueType  # 7

    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    MINUTE_FIELD_NUMBER: builtins.int
    day: global___WeeklySnapshotSchedule.WeekDay.ValueType
    """Day of the week"""
    hour: builtins.int
    """The hour of the day in UTC timezone at which the backup should be created."""
    minute: builtins.int
    """The minute of the hour at which the backup should be created."""
    def __init__(
        self,
        *,
        day: global___WeeklySnapshotSchedule.WeekDay.ValueType = ...,
        hour: builtins.int = ...,
        minute: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day", b"day", "hour", b"hour", "minute", b"minute"]) -> None: ...

global___WeeklySnapshotSchedule = WeeklySnapshotSchedule



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourcePreset(google.protobuf.message.Message):
    """A preset of resources for hardware configuration of Greenplum® hosts."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ResourcePreset._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: ResourcePreset._Type.ValueType  # 0
        MASTER: ResourcePreset._Type.ValueType  # 1
        """Greenplum® master host."""
        SEGMENT: ResourcePreset._Type.ValueType  # 2
        """Greenplum® segment host."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: ResourcePreset.Type.ValueType  # 0
    MASTER: ResourcePreset.Type.ValueType  # 1
    """Greenplum® master host."""
    SEGMENT: ResourcePreset.Type.ValueType  # 2
    """Greenplum® segment host."""

    ID_FIELD_NUMBER: builtins.int
    ZONE_IDS_FIELD_NUMBER: builtins.int
    DISK_TYPE_IDS_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    HOST_COUNT_DIVIDER_FIELD_NUMBER: builtins.int
    MAX_SEGMENT_IN_HOST_COUNT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the resource preset."""
    cores: builtins.int
    """Number of CPU cores for a Greenplum® host created with the preset."""
    memory: builtins.int
    """RAM volume for a Greenplum® host created with the preset, in bytes."""
    type: global___ResourcePreset.Type.ValueType
    """Host type."""
    host_count_divider: builtins.int
    """The number of hosts must be divisible by [host_count_divider]."""
    max_segment_in_host_count: builtins.int
    """Maximum number of segments in segment host."""
    @property
    def zone_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of availability zones where the resource preset is available."""

    @property
    def disk_type_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of availability disk types available in the resource preset."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        zone_ids: collections.abc.Iterable[builtins.str] | None = ...,
        disk_type_ids: collections.abc.Iterable[builtins.str] | None = ...,
        cores: builtins.int = ...,
        memory: builtins.int = ...,
        type: global___ResourcePreset.Type.ValueType = ...,
        host_count_divider: builtins.int = ...,
        max_segment_in_host_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cores", b"cores", "disk_type_ids", b"disk_type_ids", "host_count_divider", b"host_count_divider", "id", b"id", "max_segment_in_host_count", b"max_segment_in_host_count", "memory", b"memory", "type", b"type", "zone_ids", b"zone_ids"]) -> None: ...

global___ResourcePreset = ResourcePreset



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/storage_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/storage_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.baremetal.v1alpha import storage_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_storage__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/baremetal/v1alpha/storage_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a,yandex/cloud/baremetal/v1alpha/storage.proto\x1a\x1dyandex/cloud/validation.proto\"e\n\x0e\x44\x65\x66\x61ultStorage\x12\x18\n\x10\x63onfiguration_id\x18\x01 \x01(\t\x12\x39\n\x08storages\x18\x02 \x03(\x0b\x32\'.yandex.cloud.baremetal.v1alpha.Storage\"N\n\x18GetDefaultStorageRequest\x12\x32\n\x10\x63onfiguration_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"b\n\x1e\x42\x61tchGetDefaultStoragesRequest\x12@\n\x11\x63onfiguration_ids\x18\x01 \x03(\tB%\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x02\x32\x30\x90\xc8\x31\x01\"k\n\x1f\x42\x61tchGetDefaultStoragesResponse\x12H\n\x10\x64\x65\x66\x61ult_storages\x18\x01 \x03(\x0b\x32..yandex.cloud.baremetal.v1alpha.DefaultStorage2\x97\x03\n\x0eStorageService\x12\xb6\x01\n\nGetDefault\x12\x38.yandex.cloud.baremetal.v1alpha.GetDefaultStorageRequest\x1a..yandex.cloud.baremetal.v1alpha.DefaultStorage\">\x82\xd3\xe4\x93\x02\x38\x12\x36/baremetal/v1alpha/storages/default/{configuration_id}\x12\xcb\x01\n\x0f\x42\x61tchGetDefault\x12>.yandex.cloud.baremetal.v1alpha.BatchGetDefaultStoragesRequest\x1a?.yandex.cloud.baremetal.v1alpha.BatchGetDefaultStoragesResponse\"7\x82\xd3\xe4\x93\x02\x31\",/baremetal/v1alpha/storages/default:batchGet:\x01*Br\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.storage_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETDEFAULTSTORAGEREQUEST'].fields_by_name['configuration_id']._loaded_options = None
  _globals['_GETDEFAULTSTORAGEREQUEST'].fields_by_name['configuration_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_BATCHGETDEFAULTSTORAGESREQUEST'].fields_by_name['configuration_ids']._loaded_options = None
  _globals['_BATCHGETDEFAULTSTORAGESREQUEST'].fields_by_name['configuration_ids']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\202\3101\0051-100\212\3101\00220\220\3101\001'
  _globals['_STORAGESERVICE'].methods_by_name['GetDefault']._loaded_options = None
  _globals['_STORAGESERVICE'].methods_by_name['GetDefault']._serialized_options = b'\202\323\344\223\0028\0226/baremetal/v1alpha/storages/default/{configuration_id}'
  _globals['_STORAGESERVICE'].methods_by_name['BatchGetDefault']._loaded_options = None
  _globals['_STORAGESERVICE'].methods_by_name['BatchGetDefault']._serialized_options = b'\202\323\344\223\0021\",/baremetal/v1alpha/storages/default:batchGet:\001*'
  _globals['_DEFAULTSTORAGE']._serialized_start=195
  _globals['_DEFAULTSTORAGE']._serialized_end=296
  _globals['_GETDEFAULTSTORAGEREQUEST']._serialized_start=298
  _globals['_GETDEFAULTSTORAGEREQUEST']._serialized_end=376
  _globals['_BATCHGETDEFAULTSTORAGESREQUEST']._serialized_start=378
  _globals['_BATCHGETDEFAULTSTORAGESREQUEST']._serialized_end=476
  _globals['_BATCHGETDEFAULTSTORAGESRESPONSE']._serialized_start=478
  _globals['_BATCHGETDEFAULTSTORAGESRESPONSE']._serialized_end=585
  _globals['_STORAGESERVICE']._serialized_start=588
  _globals['_STORAGESERVICE']._serialized_end=995
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/batch_inference/v1/batch_inference_task.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/batch_inference/v1/batch_inference_task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from yandex.cloud.ai.batch_inference.v1 import inference_options_pb2 as yandex_dot_cloud_dot_ai_dot_batch__inference_dot_v1_dot_inference__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/ai/batch_inference/v1/batch_inference_task.proto\x12\"yandex.cloud.ai.batch_inference.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a:yandex/cloud/ai/batch_inference/v1/inference_options.proto\"\xc4\t\n\x12\x42\x61tchInferenceTask\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x14\n\x0coperation_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x11\n\tmodel_uri\x18\x04 \x01(\t\x12\x19\n\x11source_dataset_id\x18\x05 \x01(\t\x12X\n\x12\x63ompletion_request\x18\x06 \x01(\x0b\x32:.yandex.cloud.ai.batch_inference.v1.BatchCompletionRequestH\x00\x12M\n\x06status\x18\x07 \x01(\x0e\x32=.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.Status\x12\x19\n\x11result_dataset_id\x18\x08 \x01(\t\x12R\n\x06labels\x18\t \x03(\x0b\x32\x42.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.LabelsEntry\x12\x12\n\ncreated_by\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12Q\n\x06\x65rrors\x18\x0e \x01(\x0b\x32\x41.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.ErrorsInfo\x1a\x85\x03\n\nErrorsInfo\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12`\n\x0bline_errors\x18\x02 \x03(\x0b\x32K.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.ErrorsInfo.LineError\x12\x62\n\x0c\x62\x61tch_errors\x18\x03 \x03(\x0b\x32L.yandex.cloud.ai.batch_inference.v1.BatchInferenceTask.ErrorsInfo.BatchError\x1a\x31\n\tLineError\x12\x13\n\x0bline_number\x18\x01 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x1aZ\n\nBatchError\x12\x14\n\x0c\x62\x61tch_number\x18\x01 \x01(\x03\x12\x12\n\nfirst_line\x18\x02 \x01(\x03\x12\x11\n\tlast_line\x18\x03 \x01(\x03\x12\x0f\n\x07message\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\x42\t\n\x07requestBu\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomo'
  _globals['_BATCHINFERENCETASK_LABELSENTRY']._loaded_options = None
  _globals['_BATCHINFERENCETASK_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_BATCHINFERENCETASK']._serialized_start=220
  _globals['_BATCHINFERENCETASK']._serialized_end=1440
  _globals['_BATCHINFERENCETASK_ERRORSINFO']._serialized_start=875
  _globals['_BATCHINFERENCETASK_ERRORSINFO']._serialized_end=1264
  _globals['_BATCHINFERENCETASK_ERRORSINFO_LINEERROR']._serialized_start=1123
  _globals['_BATCHINFERENCETASK_ERRORSINFO_LINEERROR']._serialized_end=1172
  _globals['_BATCHINFERENCETASK_ERRORSINFO_BATCHERROR']._serialized_start=1174
  _globals['_BATCHINFERENCETASK_ERRORSINFO_BATCHERROR']._serialized_end=1264
  _globals['_BATCHINFERENCETASK_LABELSENTRY']._serialized_start=1266
  _globals['_BATCHINFERENCETASK_LABELSENTRY']._serialized_end=1311
  _globals['_BATCHINFERENCETASK_STATUS']._serialized_start=1313
  _globals['_BATCHINFERENCETASK_STATUS']._serialized_end=1429
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/scanner_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/scanner_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import scanner_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_scanner__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/containerregistry/v1/scanner_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a/yandex/cloud/containerregistry/v1/scanner.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"-\n\x0bScanRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"&\n\x0cScanMetadata\x12\x16\n\x0escan_result_id\x18\x01 \x01(\t\"<\n\x14GetScanResultRequest\x12$\n\x0escan_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x18GetLastScanResultRequest\x12\x1a\n\x08image_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xdc\x01\n\x16ListScanResultsRequest\x12\x1c\n\x08image_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12!\n\rrepository_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"w\n\x17ListScanResultsResponse\x12\x43\n\x0cscan_results\x18\x01 \x03(\x0b\x32-.yandex.cloud.containerregistry.v1.ScanResult\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb9\x01\n\x1aListVulnerabilitiesRequest\x12$\n\x0escan_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x81\x01\n\x1bListVulnerabilitiesResponse\x12I\n\x0fvulnerabilities\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.Vulnerability\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9b\x07\n\x0eScannerService\x12\xa0\x01\n\x04Scan\x12..yandex.cloud.containerregistry.v1.ScanRequest\x1a!.yandex.cloud.operation.Operation\"E\xb2\xd2*\x1a\n\x0cScanMetadata\x12\nScanResult\x82\xd3\xe4\x93\x02!\"\x1c/container-registry/v1/scans:\x01*\x12\xa4\x01\n\x03Get\x12\x37.yandex.cloud.containerregistry.v1.GetScanResultRequest\x1a-.yandex.cloud.containerregistry.v1.ScanResult\"5\x82\xd3\xe4\x93\x02/\x12-/container-registry/v1/scans/{scan_result_id}\x12\xb6\x01\n\x07GetLast\x12;.yandex.cloud.containerregistry.v1.GetLastScanResultRequest\x1a-.yandex.cloud.containerregistry.v1.ScanResult\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/container-registry/v1/images/{image_id}:lastScanResult\x12\xa3\x01\n\x04List\x12\x39.yandex.cloud.containerregistry.v1.ListScanResultsRequest\x1a:.yandex.cloud.containerregistry.v1.ListScanResultsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/container-registry/v1/scans\x12\xdf\x01\n\x13ListVulnerabilities\x12=.yandex.cloud.containerregistry.v1.ListVulnerabilitiesRequest\x1a>.yandex.cloud.containerregistry.v1.ListVulnerabilitiesResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/container-registry/v1/scans/{scan_result_id}:listVulnerabilitiesB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.scanner_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_SCANREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_SCANREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETSCANRESULTREQUEST'].fields_by_name['scan_result_id']._loaded_options = None
  _globals['_GETSCANRESULTREQUEST'].fields_by_name['scan_result_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETLASTSCANRESULTREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_GETLASTSCANRESULTREQUEST'].fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTSCANRESULTSREQUEST'].oneofs_by_name['id']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['repository_id']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['repository_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSCANRESULTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['scan_result_id']._loaded_options = None
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['scan_result_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTVULNERABILITIESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_SCANNERSERVICE'].methods_by_name['Scan']._loaded_options = None
  _globals['_SCANNERSERVICE'].methods_by_name['Scan']._serialized_options = b'\262\322*\032\n\014ScanMetadata\022\nScanResult\202\323\344\223\002!\"\034/container-registry/v1/scans:\001*'
  _globals['_SCANNERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_SCANNERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002/\022-/container-registry/v1/scans/{scan_result_id}'
  _globals['_SCANNERSERVICE'].methods_by_name['GetLast']._loaded_options = None
  _globals['_SCANNERSERVICE'].methods_by_name['GetLast']._serialized_options = b'\202\323\344\223\0029\0227/container-registry/v1/images/{image_id}:lastScanResult'
  _globals['_SCANNERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_SCANNERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\036\022\034/container-registry/v1/scans'
  _globals['_SCANNERSERVICE'].methods_by_name['ListVulnerabilities']._loaded_options = None
  _globals['_SCANNERSERVICE'].methods_by_name['ListVulnerabilities']._serialized_options = b'\202\323\344\223\002C\022A/container-registry/v1/scans/{scan_result_id}:listVulnerabilities'
  _globals['_SCANREQUEST']._serialized_start=278
  _globals['_SCANREQUEST']._serialized_end=323
  _globals['_SCANMETADATA']._serialized_start=325
  _globals['_SCANMETADATA']._serialized_end=363
  _globals['_GETSCANRESULTREQUEST']._serialized_start=365
  _globals['_GETSCANRESULTREQUEST']._serialized_end=425
  _globals['_GETLASTSCANRESULTREQUEST']._serialized_start=427
  _globals['_GETLASTSCANRESULTREQUEST']._serialized_end=481
  _globals['_LISTSCANRESULTSREQUEST']._serialized_start=484
  _globals['_LISTSCANRESULTSREQUEST']._serialized_end=704
  _globals['_LISTSCANRESULTSRESPONSE']._serialized_start=706
  _globals['_LISTSCANRESULTSRESPONSE']._serialized_end=825
  _globals['_LISTVULNERABILITIESREQUEST']._serialized_start=828
  _globals['_LISTVULNERABILITIESREQUEST']._serialized_end=1013
  _globals['_LISTVULNERABILITIESRESPONSE']._serialized_start=1016
  _globals['_LISTVULNERABILITIESRESPONSE']._serialized_end=1145
  _globals['_SCANNERSERVICE']._serialized_start=1148
  _globals['_SCANNERSERVICE']._serialized_end=2071
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.rpc.status_pb2
import sys
import typing
import yandex.cloud.ai.vision.v1.classification_pb2
import yandex.cloud.ai.vision.v1.face_detection_pb2
import yandex.cloud.ai.vision.v1.image_copy_search_pb2
import yandex.cloud.ai.vision.v1.text_detection_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BatchAnalyzeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANALYZE_SPECS_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to which you have access.
    Required for authorization with a user account.
    Don't specify this field if you make the request on behalf of a service account.
    """
    @property
    def analyze_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnalyzeSpec]:
        """A list of specifications. Each specification contains the file to analyze and features to use for analysis.

        Restrictions:
        * Supported file formats: `JPEG`, `PNG`.
        * Maximum file size: 1 MB.
        * Image size should not exceed 20M pixels (length x width).
        """

    def __init__(
        self,
        *,
        analyze_specs: collections.abc.Iterable[global___AnalyzeSpec] | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["analyze_specs", b"analyze_specs", "folder_id", b"folder_id"]) -> None: ...

global___BatchAnalyzeRequest = BatchAnalyzeRequest

@typing.final
class AnalyzeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Image content, represented as a stream of bytes.
    Note: As with all bytes fields, protobuffers use a pure binary representation, whereas JSON representations use base64.
    """
    signature: builtins.str
    mime_type: builtins.str
    """[MIME type](https://en.wikipedia.org/wiki/Media_type) of content (for example, `` application/pdf ``)."""
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Feature]:
        """Requested features to use for analysis.

        Max count of requested features for one file is 8.
        """

    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        signature: builtins.str = ...,
        features: collections.abc.Iterable[global___Feature] | None = ...,
        mime_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "signature", b"signature", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "features", b"features", "mime_type", b"mime_type", "signature", b"signature", "source", b"source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["content", "signature"] | None: ...

global___AnalyzeSpec = AnalyzeSpec

@typing.final
class Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Feature._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Feature._Type.ValueType  # 0
        TEXT_DETECTION: Feature._Type.ValueType  # 1
        """Text detection (OCR) feature."""
        CLASSIFICATION: Feature._Type.ValueType  # 2
        """Classification feature."""
        FACE_DETECTION: Feature._Type.ValueType  # 3
        """Face detection feature."""
        IMAGE_COPY_SEARCH: Feature._Type.ValueType  # 4
        """Image copy search."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Feature.Type.ValueType  # 0
    TEXT_DETECTION: Feature.Type.ValueType  # 1
    """Text detection (OCR) feature."""
    CLASSIFICATION: Feature.Type.ValueType  # 2
    """Classification feature."""
    FACE_DETECTION: Feature.Type.ValueType  # 3
    """Face detection feature."""
    IMAGE_COPY_SEARCH: Feature.Type.ValueType  # 4
    """Image copy search."""

    TYPE_FIELD_NUMBER: builtins.int
    CLASSIFICATION_CONFIG_FIELD_NUMBER: builtins.int
    TEXT_DETECTION_CONFIG_FIELD_NUMBER: builtins.int
    type: global___Feature.Type.ValueType
    """Type of requested feature."""
    @property
    def classification_config(self) -> global___FeatureClassificationConfig:
        """Required for the `CLASSIFICATION` type. Specifies configuration for the classification feature."""

    @property
    def text_detection_config(self) -> global___FeatureTextDetectionConfig:
        """Required for the `TEXT_DETECTION` type. Specifies configuration for the text detection (OCR) feature."""

    def __init__(
        self,
        *,
        type: global___Feature.Type.ValueType = ...,
        classification_config: global___FeatureClassificationConfig | None = ...,
        text_detection_config: global___FeatureTextDetectionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["classification_config", b"classification_config", "config", b"config", "text_detection_config", b"text_detection_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["classification_config", b"classification_config", "config", b"config", "text_detection_config", b"text_detection_config", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["config", b"config"]) -> typing.Literal["classification_config", "text_detection_config"] | None: ...

global___Feature = Feature

@typing.final
class FeatureClassificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    model: builtins.str
    """Model to use for image classification."""
    def __init__(
        self,
        *,
        model: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model", b"model"]) -> None: ...

global___FeatureClassificationConfig = FeatureClassificationConfig

@typing.final
class FeatureTextDetectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_CODES_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    model: builtins.str
    """Model to use for text detection.
    Possible values:
    * `page` (default): this model is suitable for detecting multiple text entries in an image.
    * `line`: this model is suitable for cropped images with one line of text.
    """
    @property
    def language_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of the languages to recognize text.
        Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `ru`).
        """

    def __init__(
        self,
        *,
        language_codes: collections.abc.Iterable[builtins.str] | None = ...,
        model: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language_codes", b"language_codes", "model", b"model"]) -> None: ...

global___FeatureTextDetectionConfig = FeatureTextDetectionConfig

@typing.final
class BatchAnalyzeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AnalyzeResult]:
        """Request results.
        Results have the same order as specifications in the request.
        """

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___AnalyzeResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["results", b"results"]) -> None: ...

global___BatchAnalyzeResponse = BatchAnalyzeResponse

@typing.final
class AnalyzeResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureResult]:
        """Results for each requested feature.
        Feature results have the same order as in the request.
        """

    @property
    def error(self) -> google.rpc.status_pb2.Status:
        """Return error in case of error with file processing."""

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[global___FeatureResult] | None = ...,
        error: google.rpc.status_pb2.Status | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["error", b"error"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["error", b"error", "results", b"results"]) -> None: ...

global___AnalyzeResult = AnalyzeResult

@typing.final
class FeatureResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_DETECTION_FIELD_NUMBER: builtins.int
    CLASSIFICATION_FIELD_NUMBER: builtins.int
    FACE_DETECTION_FIELD_NUMBER: builtins.int
    IMAGE_COPY_SEARCH_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def text_detection(self) -> yandex.cloud.ai.vision.v1.text_detection_pb2.TextAnnotation:
        """Text detection (OCR) result."""

    @property
    def classification(self) -> yandex.cloud.ai.vision.v1.classification_pb2.ClassAnnotation:
        """Classification result."""

    @property
    def face_detection(self) -> yandex.cloud.ai.vision.v1.face_detection_pb2.FaceAnnotation:
        """Face detection result."""

    @property
    def image_copy_search(self) -> yandex.cloud.ai.vision.v1.image_copy_search_pb2.ImageCopySearchAnnotation:
        """Image Copy Search result."""

    @property
    def error(self) -> google.rpc.status_pb2.Status:
        """Return error in case of error during the specified feature processing."""

    def __init__(
        self,
        *,
        text_detection: yandex.cloud.ai.vision.v1.text_detection_pb2.TextAnnotation | None = ...,
        classification: yandex.cloud.ai.vision.v1.classification_pb2.ClassAnnotation | None = ...,
        face_detection: yandex.cloud.ai.vision.v1.face_detection_pb2.FaceAnnotation | None = ...,
        image_copy_search: yandex.cloud.ai.vision.v1.image_copy_search_pb2.ImageCopySearchAnnotation | None = ...,
        error: google.rpc.status_pb2.Status | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["classification", b"classification", "error", b"error", "face_detection", b"face_detection", "feature", b"feature", "image_copy_search", b"image_copy_search", "text_detection", b"text_detection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["classification", b"classification", "error", b"error", "face_detection", b"face_detection", "feature", b"feature", "image_copy_search", b"image_copy_search", "text_detection", b"text_detection"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["feature", b"feature"]) -> typing.Literal["text_detection", "classification", "face_detection", "image_copy_search"] | None: ...

global___FeatureResult = FeatureResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2
import yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PrivateCloudConnectionServiceStub:
    """A set of methods for managing Private cloud connection resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.GetPrivateCloudConnectionRequest,
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection,
    ]
    """Returns the specific Private cloud connection resource.

    To get the list of available Private cloud connection resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionRequest,
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionResponse,
    ]
    """Retrieves the list of Private cloud connection resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.CreatePrivateCloudConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a private cloud connection in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.UpdatePrivateCloudConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the routing_instance_id in a private cloud connection."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.DeletePrivateCloudConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes a private cloud connection and all allocated network resouces"""

class PrivateCloudConnectionServiceAsyncStub:
    """A set of methods for managing Private cloud connection resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.GetPrivateCloudConnectionRequest,
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection,
    ]
    """Returns the specific Private cloud connection resource.

    To get the list of available Private cloud connection resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionRequest,
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionResponse,
    ]
    """Retrieves the list of Private cloud connection resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.CreatePrivateCloudConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a private cloud connection in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.UpdatePrivateCloudConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the routing_instance_id in a private cloud connection."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.DeletePrivateCloudConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes a private cloud connection and all allocated network resouces"""

class PrivateCloudConnectionServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Private cloud connection resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.GetPrivateCloudConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection]]:
        """Returns the specific Private cloud connection resource.

        To get the list of available Private cloud connection resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.ListPrivateCloudConnectionResponse]]:
        """Retrieves the list of Private cloud connection resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.CreatePrivateCloudConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a private cloud connection in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.UpdatePrivateCloudConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the routing_instance_id in a private cloud connection."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.baremetal.v1alpha.private_cloud_connection_service_pb2.DeletePrivateCloudConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes a private cloud connection and all allocated network resouces"""

def add_PrivateCloudConnectionServiceServicer_to_server(servicer: PrivateCloudConnectionServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    PICTURE_DATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the user."""
    name: builtins.str
    """Name of the user."""
    email: builtins.str
    """Email of the user."""
    picture: builtins.str
    """URL to the user's profile picture."""
    picture_data: builtins.str
    """An image content of the user's profile picture."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        email: builtins.str = ...,
        picture: builtins.str = ...,
        picture_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["email", b"email", "id", b"id", "name", b"name", "picture", b"picture", "picture_data", b"picture_data"]) -> None: ...

global___User = User
